#!/usr/bin/perl -w

use strict;
use warnings;
use Test::More qw(no_plan);
use File::Spec::Functions qw(catfile);
use Data::Dumper;

BEGIN { use_ok('Net::Snort::Parser::RuleOptions'); }

my $x = Net::Snort::Parser::RuleOptions->new();
isa_ok($x, 'Net::Snort::Parser::RuleOptions');

my %references = (
    'cve' => {
        'valid' => ['1000-1000', '1000-100'],
        'invalid' => ['asdf', '1000'],
    },
    'bugtraq' => {
        'valid' => ['1000', '10000'],
        'invalid' => ['1000l']
    }
);


sub run {
    my ($ref, $value) = @_;
    my %rule;
    return $x->reference(\%rule, join(',', $ref, $value));
}

sub is_valid {
    my ($ref, $value) = @_;
    return is(run($ref, $value), 0, $ref  . ' : valid');
}
sub is_invalid {
    my ($ref, $value) = @_;
    return is(run($ref, $value), 'Invalid reference value : '.  $value, $ref . ' : invalid');
}

foreach my $ref (keys %references) {
    map( is_valid($ref, $_), @{ $references{$ref}{'valid'} });
    map( is_invalid($ref, $_), @{ $references{$ref}{'invalid'} });
}
